Contracts
=========

This module contains all contract classes as well as helper methods for working
with these.

.. autoclass:: algotradepy.contracts.AContract
    :members:
    :undoc-members:

.. autoclass:: algotradepy.contracts.StockContract
    :members:

.. autoclass:: algotradepy.contracts.OptionContract
    :members:
    :undoc-members:

.. autoclass:: algotradepy.contracts.Right
    :members:

.. autoclass:: algotradepy.contracts.ForexContract
    :members:

.. autoclass:: algotradepy.contracts.PriceType
    :members:

.. autoclass:: algotradepy.contracts.Exchange
    :members:

.. autoclass:: algotradepy.contracts.Currency
    :members:

.. automodule:: algotradepy.contracts
    :members: are_loosely_equal_contracts